# python-homewizard-kitchen
This package connects to the HomeWizard Kitchen's websocket to get & update a device status.
This project currently only implements the Kettle device.

## Installation
```
pip install homewizard-kitchen
```

## Usage
See [example.py](example.py)

Afterwards you can use the Kettle model to update & retrieve data.